==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ColumnResizingSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { ColumnResizingSeparatorDescription } from "./ColumnResizingSeparatorDescription";
/**
 * @hidden
 */
export let ColumnResizingSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnResizingSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnResizingSeparatorDescriptionMetadata.a == null) {
                ColumnResizingSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnResizingSeparatorDescriptionMetadata.c(ColumnResizingSeparatorDescriptionMetadata.a);
            }
            if (a.j(ColumnResizingSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnResizingSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("ActualOpacity", "Number:double");
            a.item("Opacity", "Number:double");
        }
        static d(a) {
            ColumnResizingSeparatorDescriptionMetadata.b(a);
            a.aa("ColumnResizingSeparator", () => new ColumnResizingSeparatorDescription());
            a.z("ColumnResizingSeparator", ColumnResizingSeparatorDescriptionMetadata.a);
        }
    }
    ColumnResizingSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnResizingSeparatorDescriptionMetadata, 'ColumnResizingSeparatorDescriptionMetadata');
    ColumnResizingSeparatorDescriptionMetadata.a = null;
    return ColumnResizingSeparatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnResizingSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { ColumnResizingSeparatorDescription } from "./ColumnResizingSeparatorDescription";
/**
 * @hidden
 */
export let ColumnResizingSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnResizingSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnResizingSeparatorDescriptionMetadata.a == null) {
                ColumnResizingSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnResizingSeparatorDescriptionMetadata.c(ColumnResizingSeparatorDescriptionMetadata.a);
            }
            if (a.k(ColumnResizingSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnResizingSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("ActualOpacity", "Number:double");
            a.item("Opacity", "Number:double");
        }
        static d(a) {
            ColumnResizingSeparatorDescriptionMetadata.b(a);
            a.ac("ColumnResizingSeparator", () => new ColumnResizingSeparatorDescription());
            a.ab("ColumnResizingSeparator", ColumnResizingSeparatorDescriptionMetadata.a);
        }
    }
    ColumnResizingSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnResizingSeparatorDescriptionMetadata, 'ColumnResizingSeparatorDescriptionMetadata');
    ColumnResizingSeparatorDescriptionMetadata.a = null;
    return ColumnResizingSeparatorDescriptionMetadata;
})();
